# Installation

0. Install the package

        pip install wagtail-advanced-form-builder
        
0. Add the app to your INSTALLED_APPS.

        INSTALLED_APPS = [
            ...
            'wagtail_advanced_form_builder',
            ...
        ]        
        
0. Run migrations

        ./manage.py migrate
        
                
        
        
